import { Injectable } from '@nestjs/common';
import { BaseUpdateManager } from 'src/core/modules/domain/usecase/managers/base-update.manager';
import {
  EventTopics,
  columnUniques,
  validateRelations,
} from 'src/core/strings/constants/interface.constants';
import { SalesPriceFormulaModel } from 'src/modules/transaction/sales-price-formula/data/models/sales-price-formula.model';
import { ProfitShareFormulaUpdatedEvent } from '../../entities/event/profit-share-formula-updated.event';
import { SalesPriceFormulaEntity } from 'src/modules/transaction/sales-price-formula/domain/entities/sales-price-formula.entity';
import { In } from 'typeorm';
import { STATUS } from 'src/core/strings/constants/base.constants';
import { calculateProfitFormula } from 'src/modules/transaction/sales-price-formula/domain/usecases/managers/helpers/calculation-formula.helper';
import { FormulaType } from 'src/modules/transaction/sales-price-formula/constants';

@Injectable()
export class UpdateProfitShareFormulaManager extends BaseUpdateManager<SalesPriceFormulaEntity> {
  async validateProcess(): Promise<void> {
    const taxes = await this.dataServiceFirstOpt.getManyByOptions({
      where: {
        status: In([STATUS.ACTIVE]),
      },
    });

    calculateProfitFormula(this.data.formula_string, taxes, 10000, 50, true);
    return;
  }

  async beforeProcess(): Promise<void> {
    return;
  }

  async afterProcess(): Promise<void> {
    const additionalFormula = this.data.additional;
    for (const additional of additionalFormula) {
      /**
       * Find formula for variable
       * If the formula doesn't exist, then create data for save
       */
      const formula = (await this.dataService.getOneByOptions({
        where: {
          value_for: additional.value_for,
        },
      })) ?? {
        editor_id: this.user.id,
        editor_name: this.user.name,
        updated_at: new Date().getTime(),
        created_at: new Date().getTime(),
        type: FormulaType.PROFIT_SHARE,
      };

      // Update formula value to exist formula or new formula
      formula.formula_render = additional.formula_render;
      formula.formula_string = additional.formula_string;
      formula.value_for = additional.value_for;

      /**
       * This function is create, but inside function is save
       * So, if the id is provide, the data will be update instead create new data
       */
      this.dataService.create(null, null, formula);
    }
    return;
  }

  get validateRelations(): validateRelations[] {
    return [];
  }

  get uniqueColumns(): columnUniques[] {
    return [];
  }

  get entityTarget(): any {
    return SalesPriceFormulaModel;
  }

  get eventTopics(): EventTopics[] {
    return [
      {
        topic: ProfitShareFormulaUpdatedEvent,
      },
    ];
  }
}
